summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtexturebaseedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtexturebaseedit.h')
-rw-r--r--kpovmodeler/pmtexturebaseedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmtexturebaseedit.h b/kpovmodeler/pmtexturebaseedit.h
index 8178b612..3969c7b0 100644
--- a/kpovmodeler/pmtexturebaseedit.h
+++ b/kpovmodeler/pmtexturebaseedit.h
@@ -39,9 +39,9 @@ class PMTextureBaseEdit : public PMNamedObjectEdit
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMTextureBaseEdit with tqparent and name
*/
- PMTextureBaseEdit( TQWidget* tqparent, const char* name = 0 );
+ PMTextureBaseEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMTextureBaseEdit : public PMNamedObjectEdit
public:
/**
- * Creates a PMTextureBaseEdit with tqparent and name
+ * Creates a PMTextureBaseEdit with parent and name
*/